This is an example of distributing an application that uses Pygame.

To build the installer, run:

    pynsist installer.cfg

The *aliens* game is an example included with Pygame itself, so there's no code
here! Other examples show how to distribute application code.
